@@ -1990,7 +1990,7 @@ int evaluate_body( struct object *args, int *fail )
             char *name = NULL;
             int sym = 0, t, evaluated = 0;
       #ifdef DEBUG
-            int level = 0;
+            long int level = 0;
       #endif
             struct object *car, *cdr;
 
@@ -2143,7 +2143,7 @@ int evaluate_body( struct object *args, int *fail )
 #ifdef DEBUG
    if ( ! result && level != stack->used - 1 )
    {
-      fprintf( stderr, "[stack corrupted by: %s: before: %d, after: %d\n]",
+      fprintf( stderr, "[stack corrupted by: %s: before: %ld, after: %ld\n]",
                ( name == NULL ? car->data.atom->syntax : name ),
                level, stack->used );
       exit( 1 );
@@ -2440,7 +2440,7 @@ int evaluate()
       char *name = NULL;
       int sym = 0;
 #ifdef DEBUG
-      int level = 0;
+      long int level = 0;
 #endif
       struct object *car, *cdr;
 
@@ -2581,7 +2581,7 @@ int evaluate()
 #ifdef DEBUG
       if ( ! result && level != stack->used - 1 )
       {
-         fprintf( stderr, "stack corrupted by: %s: before: %d, after: %d\n",
+         fprintf( stderr, "stack corrupted by: %s: before: %ld, after: %ld\n",
                   ( name == NULL ? car->data.atom->syntax : name ),
                   level, stack->used );
          exit( 1 );
@@ -3024,7 +3024,7 @@ void collect_garbage()
    sweep_atoms();
 
 #ifdef DEBUG
-   fprintf( stderr, "done: objects reclaimed: %d, atoms reclaimed: %d]\n",
+   fprintf( stderr, "done: objects reclaimed: %ld, atoms reclaimed: %ld]\n",
             reclaimed_objects->used, reclaimed_atoms->used );
 #endif
 }
