@@ -250,8 +250,7 @@ struct atom
       struct lstring *string;
 
       union stack_u *record;
-      int number;
-
+      long int number;
    } data;
 
    int flags;
@@ -666,7 +665,6 @@ FUNC( extend );
 FUNC( for );
 FUNC( iterate );
 FUNC( dynamic_extent );
-FUNC( timediff );
 FUNC( timethen );
 FUNC( inc );
 FUNC( dec );
@@ -776,7 +774,6 @@ FUNC( bg_white );
 
 FUNC( isatty );
 FUNC( sleep );
-FUNC( unsigned );
 FUNC( get_scgi_header );
 
 FUNC( form_decode );
@@ -1025,7 +1022,6 @@ int ( *intrinsics[] )( char *, struct object * ) =
    do_for,
    do_iterate,
    do_dynamic_extent,
-   do_timediff,
    do_timethen,
    do_inc,
    do_dec,
@@ -1349,7 +1345,6 @@ char *intrinsic_syntax[] =
    "<FOR>",                 "for",
    "<ITERATE>",             "iterate",
    "<DYNAMIC_EXTENT>",      "dynamic_extent",
-   "<TIMEDIFF>",            "timediff",
    "<TIMETHEN>",            "timethen",
    "<INC>",                 "inc",
    "<DEC>",                 "dec",
